import { motion } from 'framer-motion';
import { Link } from 'react-router-dom';
import { Project } from '../types';
import { lazy, Suspense } from 'react';
import { projects as projectsData } from '../data/projects';

// Lazy load the HeroAnimation component
const HeroAnimation = lazy(() => import('../components/HeroAnimation'));

const projects: Project[] = projectsData.map(project => ({
  id: project.id,
  title: project.title,
  description: project.subtitle,
  image: project.cardImage
}));

const Home = () => {
  return (
    <div className="min-h-screen">
      {/* Hero Section */}
      <section className="min-h-screen flex items-center px-4 md:px-8 lg:px-16 py-20">
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-8 items-center w-full">
          {/* Text Content */}
          <motion.div
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.8 }}
          >
            <h1 className="text-2xl sm:text-3xl md:text-4xl lg:text-6xl xl:text-7xl font-bold mb-6 md:mb-8 leading-tight">
              Hi, I'm Tony, Product Designer crafting data-driven experiences for next-gen products.
            </h1>
            <p className="text-base sm:text-lg md:text-xl lg:text-2xl text-gray-200 mb-8 md:mb-12">
              I combine data-driven insights with strong visual design to create digital products
              that solve complex problems and delight users.
            </p>
          </motion.div>

          {/* Animation */}
          <motion.div
            initial={{ opacity: 0 }}
            animate={{ opacity: 1 }}
            transition={{ duration: 0.8, delay: 0.2 }}
            className="w-full h-[500px]"
          >
            <Suspense fallback={<div className="w-full h-full bg-gray-100 dark:bg-gray-800 rounded-lg animate-pulse" />}>
              <HeroAnimation />
            </Suspense>
          </motion.div>
        </div>
      </section>

      {/* Projects Section */}
      <section className="px-4 md:px-8 lg:px-16 pb-20">
        <motion.div
          initial={{ opacity: 0 }}
          whileInView={{ opacity: 1 }}
          transition={{ duration: 0.8 }}
          viewport={{ once: true, margin: "-100px" }}
        >
          <h2 className="text-3xl font-bold mb-12">Recent Work</h2>
          <div className="grid grid-cols-1 gap-8">
            {projects.map((project, index) => (
              <motion.div
                key={project.id}
                initial={{ opacity: 0, y: 50 }}
                whileInView={{ opacity: 1, y: 0 }}
                transition={{ 
                  duration: 0.8,
                  delay: 0.2,
                  ease: [0.21, 0.45, 0.32, 0.9]
                }}
                viewport={{ once: true, margin: "-100px" }}
                className="w-full"
              >
                {project.id === 'commons-ai' ? (
                  <div className="block">
                    <div className="relative aspect-[16/9] overflow-hidden rounded-2xl group">
                      {/* Background image */}
                      <div className="relative w-full h-full">
                        <img
                          src={project.image}
                          alt={project.title}
                          loading={index === 0 ? "eager" : "lazy"}
                          fetchPriority={index === 0 ? "high" : "low"}
                          className="w-full h-full object-cover opacity-70"
                        />
                        {/* Gradient overlay */}
                        <div className="absolute inset-0 bg-[radial-gradient(circle_at_center,_transparent_0%,_rgba(0,0,0,0.4)_30%,_rgba(0,0,0,0.8)_100%)]"></div>
                      </div>
                      
                      {/* Text overlay */}
                      <div className="absolute inset-0 z-20 flex flex-col justify-center px-6 sm:px-8 md:pl-16 md:pr-8 py-8">
                        <div className="w-full sm:w-2/3 md:w-1/2 lg:w-2/5 xl:w-1/3">
                          <h3 className="text-2xl sm:text-3xl md:text-4xl lg:text-5xl font-bold mb-2 sm:mb-4 text-white">
                            {project.title}
                          </h3>
                          <p className="text-sm sm:text-md md:text-lg text-gray-200 mb-4 sm:mb-8">
                            {project.description}
                          </p>
                          <div className="inline-block">
                            <span className="btn btn-white opacity-75 cursor-default text-sm sm:text-base">
                              Coming Soon
                            </span>
                          </div>
                        </div>
                      </div>
                    </div>
                  </div>
                ) : (
                  <Link 
                    to={`/projects/${project.id}`} 
                    className="block"
                    onClick={() => {
                      // Force immediate scroll to top when clicking project link
                      window.scrollTo({
                        top: 0,
                        left: 0,
                        behavior: 'auto'
                      });
                    }}
                  >
                    <div className="relative aspect-[16/9] overflow-hidden rounded-2xl group">
                      {/* Background image */}
                      <div className="relative w-full h-full transition-transform duration-700 ease-out group-hover:scale-105">
                        <img
                          src={project.image}
                          alt={project.title}
                          loading={index === 0 ? "eager" : "lazy"}
                          fetchPriority={index === 0 ? "high" : "low"}
                          className="w-full h-full object-cover"
                        />
                        {/* Gradient overlay */}
                        <div className="absolute inset-0 bg-[radial-gradient(circle_at_center,_transparent_0%,_rgba(0,0,0,0.2)_30%,_rgba(0,0,0,0.7)_100%)] transition-opacity duration-700 ease-out group-hover:opacity-90"></div>
                      </div>
                      
                      {/* Text overlay */}
                      <div className="absolute inset-0 z-20 flex flex-col justify-center px-6 sm:px-8 md:pl-16 md:pr-8 py-8">
                        <div className="w-full sm:w-2/3 md:w-1/2 lg:w-2/5 xl:w-1/3">
                          <h3 className="text-2xl sm:text-3xl md:text-4xl lg:text-5xl font-bold mb-2 sm:mb-4 text-white">
                            {project.title}
                          </h3>
                          <p className="text-sm sm:text-md md:text-lg text-gray-200 mb-4 sm:mb-8">
                            {project.description}
                          </p>
                          <div className="inline-block">
                            <span className="btn btn-white text-sm sm:text-base">
                              {project.id === 'lunchbox' || project.id === 'booz-allen' ? 'Password Required' : 'View Work'}
                              <span className="transform text-black">→</span>
                            </span>
                          </div>
                        </div>
                      </div>
                    </div>
                  </Link>
                )}
              </motion.div>
            ))}
          </div>
        </motion.div>
      </section>

      {/* Contact Section */}
      <section className="px-4 md:px-8 lg:px-16 pb-20">
        <motion.div
          initial={{ opacity: 0, y: 30 }}
          whileInView={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.8 }}
          viewport={{ once: true, margin: "-100px" }}
          className="max-w-4xl"
        >
          <h2 className="text-3xl font-bold mb-6">Let's work together</h2>
          <p className="text-xl text-gray-200 mb-8">
            I'm always interested in new opportunities to create impactful digital experiences.
          </p>
          <Link
            to="/contact"
            className="inline-flex items-center text-lg font-medium group hover-underline"
          >
            <span className="mr-2">Get in touch</span>
            <span>→</span>
          </Link>
        </motion.div>
      </section>
    </div>
  );
};

export default Home; 